@@ -9,9 +9,9 @@
 #include <QtCore/QDateTime>
 #include <Soprano/Vocabulary/RDF>
 
-#include <dms-copy/simpleresource.h>
+#include <nepomuk2/simpleresource.h>
 
-namespace Nepomuk {
+namespace Nepomuk2 {
 namespace NCAL {
 /**
  * 
@@ -19,7 +19,7 @@ namespace NCAL {
 class RecurrenceRule
 {
 public:
-    RecurrenceRule(Nepomuk::SimpleResource* res)
+    RecurrenceRule(Nepomuk2::SimpleResource* res)
       : m_res(res)
     {}
 
@@ -557,7 +557,7 @@ protected:
     virtual QUrl resourceType() const { return QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/04/02/ncal#RecurrenceRule", QUrl::StrictMode); }
 
 private:
-    Nepomuk::SimpleResource* m_res;
+    Nepomuk2::SimpleResource* m_res;
 };
 }
 }
