@@ -53,7 +53,7 @@ ResourcesManagementWidget::ResourcesManagementWidget( QWidget *parent,  const QS
     d->wantedMimeTypes = args;
     d->ui.setupUi( this );
 
-    d->ui.resourcesList->agentFilterProxyModel()->addCapabilityFilter( "Resource" );
+    d->ui.resourcesList->agentFilterProxyModel()->addCapabilityFilter( QLatin1String("Resource") );
     foreach ( const QString& type, d->wantedMimeTypes )
         d->ui.resourcesList->agentFilterProxyModel()->addMimeTypeFilter( type );
     connect( d->ui.resourcesList->view()->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
