@@ -116,7 +116,7 @@ void AddCollectionTask::onSubscribeDone( KJob *job )
 
   foreach ( const QByteArray &entry, annotations.keys() ) { //krazy:exclude=foreach
     KIMAP::SetMetaDataJob *job = new KIMAP::SetMetaDataJob( m_session );
-    if ( serverCapabilities().contains( "METADATA" ) ) {
+    if ( serverCapabilities().contains( QLatin1String("METADATA") ) ) {
       job->setServerCapability( KIMAP::MetaDataJobBase::Metadata );
     } else {
       job->setServerCapability( KIMAP::MetaDataJobBase::Annotatemore );
