@@ -130,7 +130,7 @@ void ChangeCollectionTask::doStart( KIMAP::Session *session )
 
       foreach ( const QByteArray &entry, annotations.keys() ) { //krazy:exclude=foreach
         KIMAP::SetMetaDataJob *job = new KIMAP::SetMetaDataJob( session );
-        if ( serverCapabilities().contains( "METADATA" ) ) {
+        if ( serverCapabilities().contains( QLatin1String("METADATA") ) ) {
           job->setServerCapability( KIMAP::MetaDataJobBase::Metadata );
         } else {
           job->setServerCapability( KIMAP::MetaDataJobBase::Annotatemore );
