@@ -23,27 +23,15 @@
 #include <QByteArray>
 
 #include <kolabdefinitions.h> //libkolab
+#include <formathelpers.h> //libkolab
 
 namespace Kolab {
-  enum FolderType {
-    MailType = 0,
-    ContactType,
-    EventType,
-    TaskType,
-    JournalType,
-    NoteType,
-    ConfigurationType,
-    FreebusyType,
-    FileType,
-    LastType
-  };
-
   FolderType folderTypeFromString( const QByteArray &folderTypeName );
 }
 
 namespace KolabV2 {
 
-#define PRODUCT_ID "Akonadi-KolabResource"
+#define PRODUCT_ID QLatin1String("Akonadi-KolabResource")
 
   enum FolderType {
     Mail = 0,
